#
# spec file for package python-Flask-Admin
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-Flask-Admin
Version:        1.6.1
Release:        4.3
Summary:        Extensible admin interface framework for Flask
License:        BSD-3-Clause
URL:            https://github.com/flask-admin/flask-admin/
Source:         https://files.pythonhosted.org/packages/source/F/Flask-Admin/Flask-Admin-%{version}.tar.gz
# PATCH-FIX-OPENSUSE Flask-BabelEx has been firmly deprecated, switch to Babel
# directly.
Patch0:         switch-to-babel.patch
# cherry-picks from https://github.com/flask-admin/flask-admin/pull/2328 Support latest flask, sqlalchemy, flask-sqlalchemy and wtforms
Patch1:         model-from-model.patch
Patch2:         reverse-relation-for-model.patch
Patch3:         bytes-not-str.patch
BuildRequires:  %{python_module Flask >= 0.7}
BuildRequires:  %{python_module Flask-Babel}
BuildRequires:  %{python_module Flask-SQLAlchemy}
BuildRequires:  %{python_module Pillow >= 3.3.2}
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module SQLAlchemy-Utils}
BuildRequires:  %{python_module SQLAlchemy}
BuildRequires:  %{python_module WTForms}
BuildRequires:  %{python_module arrow}
BuildRequires:  %{python_module colour}
BuildRequires:  %{python_module peewee}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requre}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Flask >= 0.7
Requires:       python-SQLAlchemy
Requires:       python-WTForms
BuildArch:      noarch
%python_subpackages

%description
Flask-Admin is a Flask extension that lets the user add admin
interfaces to Flask applications.

It is inspired by the django-admin Python package, though the
developer has more control over the look, feel and functionality of
the resulting application.

%prep
%autosetup -p1 -n Flask-Admin-%{version}

# remove contrib tests that pull in too many dependencies
rm -rf flask_admin/tests/geoa
rm -rf flask_admin/tests/{mongoengine,pymongo}
rm -rf flask_admin/tests/peeweemodel
rm -f flask_admin/tests/sqla/test_postgres.py
# these tests try to write to protected dirs in the OBS
rm -f flask_admin/tests/test_form_upload.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest -k 'not test_model and not test_inline_form_base_class and not test_safe_redirect'

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/flask_admin
%{python_sitelib}/Flask_Admin-%{version}.dist-info

%changelog
* Fri Feb  9 2024 Dirk Müller <dmueller@suse.com>
- add %%sle15_python_module_pythons
* Tue Oct 24 2023 Markéta Machová <mmachova@suse.com>
- Add few patches to fix tests (from gh#flask-admin/flask-admin#2328):
  * model-from-model.patch
  * reverse-relation-for-model.patch
  * bytes-not-str.patch
* Mon Jul 10 2023 Steve Kowalik <steven.kowalik@suse.com>
- Add patch switch-to-babel.patch:
  * Use Flask-Babel, rather than Flask-BabelEx.
- Skip a recalcitrant test.
* Mon Jun 19 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.6.1:
  * No upstream changelog, issue filed.
- Drop patches redirect-location-assertions.patch, fix-tests.patch.
- Pin SQLAlchemy requirement to < 2.
- Switch to pyproject macros.
* Tue Jan  3 2023 Daniel Garcia <daniel.garcia@suse.com>
- Add fix-tests.patch to make tests compatible with latest Flask release
  * gh#flask-admin/flask-admin#2309
  * gh#flask-admin/flask-admin#2316
* Fri Jun 24 2022 Steve Kowalik <steven.kowalik@suse.com>
- Add patch redirect-location-assertions.patch:
  * Remove hostname when checking location from redirects.
- Add PyYAML and requre to BuildRequires.
* Sat Feb 19 2022 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
  * skip python 2 builds
  * removed patches, both included upstream (remove_nose.patch, support-new-wtforms.patch)
- update to version 1.6.0:
  * Dropped Python 2 support
  * WTForms 3.0 support
  * Various fixes
* Fri Aug  6 2021 Steve Kowalik <steven.kowalik@suse.com>
- Add patch support-new-wtforms.patch:
  * Support new WTForms.
- Skip two recalcitrant tests.
* Tue Jun  1 2021 Matej Cepl <mcepl@suse.com>
- Update to 1.5.8:
  - SQLAlchemy 1.4/2.0, 1.4.5+ compatibility fixes
  - Redis CLI fixes
  - Bootstrap 4 support!
  - Added hook for custom SQLAlchemy models initializers
- Patch remove_nose.patch rebased.
* Thu Oct 29 2020 Matej Cepl <mcepl@suse.com>
- Add remove_nose.patch to remove dependency on nose
  (gh#flask-admin/flask-admin#2047).
* Mon Sep 28 2020 Hans-Peter Jansen <hpj@urpla.net>
- Exclude a failing test
* Mon Apr 20 2020 Petr Cervinka <petr@cervinka.net>
- Fix build without python2
* Sat Apr 11 2020 Arun Persaud <arun@gmx.de>
- update to version 1.5.6:
  * SQLAlchemy 1.3.6 compatibility fix
  * Python 3.8 support
* Sat Feb  8 2020 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
- update to version 1.5.5:
  * Werkzeug 1.0 compatibility fix
  * Use fa-circle-o icon for unchecked booleans
  * A few SQLAlchemy-related bug fixes
* Sat Oct 19 2019 Arun Persaud <arun@gmx.de>
- specfile:
  * update copyright year
  * updated required pillow version
  * require arrow, colour, sqlalchemy-utils for tests
- update to version 1.5.4:
  * Fix display of inline x-editable boolean fields on list view
  * Add support for several SQLAlchemy-Utils data types
  * Support searching on SQLAlchemy hybrid properties
  * Extra URL paramaters are now propagated to the next page when
    searching / filtering
  * Add enum34 dependency when running on legacy Python version
  * Update Mapbox API v1 URL format
  * Update jQuery and moment dependencies in templates
  * Fixed a datepicker issue, where only dates up to 2015 were showing
    up
  * Updated Pillow dependency version
* Sun Dec 30 2018 Arun Persaud <arun@gmx.de>
- specfile:
  * be more specific in %%files section
- update to version 1.5.3:
  * Fixed XSS vulnerability
  * Support nested categories in the navbar menu
  * SQLAlchemy
    + sort on multiple columns with column_default_sort
    + sort on related models in column_sortable_list
    + fix: inline model forms can now also be used for models with
    multiple primary keys
    + support for using mapped column_property
  * Upgrade Leaflet and Leaflet.draw plugins, used for geoalchemy
    integration
  * Specify minimum_input_length for ajax widget
  * Peewee: support composite keys
  * MongoEngine: when searching/filtering the input is now regarded as
    case-insensitive by default
  * FileAdmin
    + handle special characters in filename
    + fix a bug with listing directories on Windows
    + avoid raising an exception when unknown sort parameter is
    encountered
  * WTForms 3 support
* Tue Oct 30 2018 Jan Engelhardt <jengelh@inai.de>
- Trim bias and filler wording from descriptions.
* Tue Oct 30 2018 Tomáš Chvátal <tchvatal@suse.com>
- Initial commit, needed by acitoolkit
